@@ -199,8 +199,8 @@ class Scraper:
             return eval('element ' + condition)
         '''
 
-    def hover(self, path: str, element: any=None, is_error: bool=True) -> None:
-        self.on_hover(path=path, element=element, is_error=is_error) 
+    def hover(self, path: str, element: any=None, is_error: bool=True, timeout: int=0) -> None:
+        self.on_hover(path=path, element=element, is_error=is_error, timeout=timeout)
 
     def enter_text(self, path: str, text: str, element: any=None, clear: bool=False, timeout: int=0, is_error: bool=False):
         return self.on_enter_text(path=path, text=text, element=element, clear=clear, timeout=timeout, is_error=is_error)
